pub struct BlockEntityType {
pub key: Identifier,
}Expand description
Represents a block entity type in Minecraft. Block entities are used for blocks that need to store additional data beyond their block state, such as chests, furnaces, signs, etc.
Fields
key: IdentifierTrait Implementations
Sourceimpl Debug for BlockEntityType
impl Debug for BlockEntityType